pub enum PositionType {
SelfDirected,
ParentDirected,
}Expand description
The position type determines whether a node will be positioned in-line with its siblings or seperate
Variants
SelfDirected
Node is positioned relative to parent but ignores its siblings
ParentDirected
Node is positioned relative to parent and in-line with siblings