pub enum ButtonEvent {
Pressed,
Released,
Press,
Release,
SetLabel(String),
SetKey(Code),
}Expand description
Events sent when interacting with a button and events to set properties of a button
Variants
Pressed
Emitted by a button when the button is pressed
Released
Emitted by a button when the button is released
Press
Received by the button and triggers the on_press event to be emitted
Release
Received by the button and triggers the on_release event to be emitted
SetLabel(String)
Sets the label of the button
SetKey(Code)
Sets the keycode for triggering the button with the keyboard