Event

Struct Event 

pub struct Event {
    pub origin: Entity,
    pub target: Entity,
    pub propagation: Propagation,
    pub consumable: bool,
    pub unique: bool,
    pub order: i32,
    pub message: Box<dyn Message>,
    /* private fields */
}
An event is a wrapper around a message and provides metadata on how the event should be propagated through the tree

Fields

origin: Entitytarget: Entitypropagation: Propagationconsumable: boolunique: boolorder: i32message: Box<dyn Message>

Implementations

Source

impl Event

pub fn new<M>(message: M) -> Event
where M: Message,

Creates a new event with a specified message

pub fn target(self, entity: Entity) -> Event

Sets the target of the event

pub fn origin(self, entity: Entity) -> Event

Sets the origin of the event

pub fn unique(self) -> Event

Specifies that the event is unique (only one of this event type should exist in the event queue at once)

pub fn propagate(self, propagation: Propagation) -> Event

Sets the propagation of the event

pub fn direct(self, entity: Entity) -> Event

pub fn consume(&mut self)

Consumes the event (prevents the event from continuing on its propagation path)